| Title: | Hierarchical Latent Space Network Model |
|---|---|
| Description: | Fits latent space models for single networks and hierarchical latent space models for ensembles of networks as described in Sweet, Thomas & Junker (2013). |
| Authors: | Samrachana Adhikari [aut], Tracy Sweet [aut, cre] |
| Maintainer: | Tracy Sweet <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.9.2 |
| Built: | 2026-05-10 09:40:01 UTC |
| Source: | https://github.com/cran/HLSM |
Function plot posterior summaries (boxplots) for regression coefficients
HLSMcovplots(fitted.model, burnin=0, thin=1, verbose=TRUE)HLSMcovplots(fitted.model, burnin=0, thin=1, verbose=TRUE)
fitted.model |
Model fit using HLSM fitting function; should be a HLSM or LSM object |
burnin |
Amount of burnin to remove |
thin |
Amount to thin each chain |
verbose |
logical to indicate whether message about order of covariates is included with plots |
The plots show posterior means and 50 and 95 percent equal-tailed credible intervals.
No return value, makes a plot in plotting window
Sam Adhikari & Tracy Sweet
Tracy M. Sweet, Andrew C. Thomas and Brian W. Junker (2013), "Hierarchical Network Models for Education Research: Hierarchical Latent Space Models", Journal of Educational and Behavorial Statistics.
Function to compute and report diagnostic plots and statistics for a single or multiple HLSM objects.
HLSMdiag(object, burnin = 0, diags = c('psrf', 'raftery', 'traceplot', 'autocorr'), col = 1:6, lty = 1)HLSMdiag(object, burnin = 0, diags = c('psrf', 'raftery', 'traceplot', 'autocorr'), col = 1:6, lty = 1)
object |
object or list of objects of class 'HLSM' returned by |
burnin |
numeric value to burn the chain while extracting results from the 'HLSM'object. Default is |
diags |
a character vector that is a subset of |
col |
a character or integer vector specifying the colors for the traceplot and autocorr plot |
lty |
a character or integer vector specifying the linetype for the traceplot and autocorr plot |
Returns an object of class "HLSMdiag". It is a list that contains variable-level diagnostic tables from either or both of the raftery diagnostic and psrf diagnostic.
call |
the matched call. |
raftery |
list of matrices of suggested niters, burnin, and thinning for each chain. |
psrf |
list containing |
Christian Meyer
Function to run the MCMC sampler to draw from the posterior distribution of intercept, slopes, and latent positions. HLSMrandomEF( ) fits random effects model; HLSMfixedEF( ) fits fixed effects model; LSM( ) fits single network model.
HLSMrandomEF(Y,edgeCov=NULL, receiverCov = NULL, senderCov = NULL, FullX = NULL,initialVals = NULL, priors = NULL, tune = NULL, tuneIn = TRUE,dd=2, niter, verbose=TRUE) HLSMfixedEF(Y,edgeCov=NULL, receiverCov = NULL, senderCov = NULL, FullX = NULL, initialVals = NULL, priors = NULL, tune = NULL, tuneIn = TRUE,dd=2, estimate.intercept=FALSE, niter, verbose=TRUE) LSM(Y,edgeCov=NULL, receiverCov = NULL, senderCov = NULL, FullX = NULL,initialVals = NULL, priors = NULL, tune = NULL, tuneIn = TRUE,dd=2, estimate.intercept=FALSE, niter, verbose=TRUE) getBeta(object, burnin = 0, thin = 1) getIntercept(object, burnin = 0, thin = 1) getLS(object, burnin = 0, thin = 1) getLikelihood(object, burnin = 0, thin = 1)HLSMrandomEF(Y,edgeCov=NULL, receiverCov = NULL, senderCov = NULL, FullX = NULL,initialVals = NULL, priors = NULL, tune = NULL, tuneIn = TRUE,dd=2, niter, verbose=TRUE) HLSMfixedEF(Y,edgeCov=NULL, receiverCov = NULL, senderCov = NULL, FullX = NULL, initialVals = NULL, priors = NULL, tune = NULL, tuneIn = TRUE,dd=2, estimate.intercept=FALSE, niter, verbose=TRUE) LSM(Y,edgeCov=NULL, receiverCov = NULL, senderCov = NULL, FullX = NULL,initialVals = NULL, priors = NULL, tune = NULL, tuneIn = TRUE,dd=2, estimate.intercept=FALSE, niter, verbose=TRUE) getBeta(object, burnin = 0, thin = 1) getIntercept(object, burnin = 0, thin = 1) getLS(object, burnin = 0, thin = 1) getLikelihood(object, burnin = 0, thin = 1)
Y |
input outcome for different networks. Y can either be (i). list of sociomatrices for (ii). list of data frame with columns (iii). a dataframe with columns named as follows: |
edgeCov |
data frame to specify edge level covariates with (i). a column for network id named (ii). a column for sender node named (iii). a column for receiver nodes named (iv). columns for values of each edge level covariates. |
receiverCov |
a data frame to specify nodal covariates as edge receivers with (i.) a column for network id named (ii.) a column (iii). the rest for respective node level covariates. |
senderCov |
a data frame to specify nodal covariates as edge senders with (i). a column for network id named (ii). a column (iii). the rest for respective node level covariates. |
FullX |
list of numeric arrays of dimension |
initialVals |
an optional list of values to initialize the chain. If For fixed effect model For random effect model
|
priors |
an optional list to specify the hyper-parameters for the prior distribution of the paramters.
If priors =
|
tune |
an optional list of tuning parameters for tuning the chain. If tune =
|
tuneIn |
a logical to indicate whether tuning is needed in the MCMC sampling. Default is |
dd |
dimension of latent space. |
estimate.intercept |
When TRUE, the intercept will be estimated. If the variance of the latent positions are of interest, intercept=FALSE will allow users to obtain a unique variance. The intercept can also be inputed by the user. |
niter |
number of iterations for the MCMC chain. |
object |
object of class 'HLSM' returned by |
burnin |
numeric value to burn the chain while extracting results from the 'HLSM'object. Default is |
thin |
numeric value by which the chain is to be thinned while extracting results from the 'HLSM' object. Default is |
verbose |
logical value; TRUE results in messages during MCMC tuning |
The HLSMfixedEF and HLSMrandomEF functions will not automatically assess thinning and burn-in. To ensure appropriate inference, see HLSMdiag.
See also LSM for fitting network data from a single network.
Returns an object of class "HLSM". It is a list with following components:
draws |
list of posterior draws for each parameters. |
acc |
list of acceptance rates of the parameters. |
call |
the matched call. |
tune |
final tuning values |
Sam Adhikari & Tracy Sweet
Tracy M. Sweet, Andrew C. Thomas and Brian W. Junker (2013), "Hierarchical Network Models for Education Research: Hierarchical Latent Space Models", Journal of Educational and Behavorial Statistics.
library(HLSM) data(schoolsAdviceData) #Set values for the inputs of the function priors = NULL tune = NULL initialVals = NULL niter = 10 lsm.fit = LSM(Y=School9Network,edgeCov=School9EdgeCov, senderCov=School9NodeCov, receiverCov=School9NodeCov, estimate.intercept=0, niter = niter)library(HLSM) data(schoolsAdviceData) #Set values for the inputs of the function priors = NULL tune = NULL initialVals = NULL niter = 10 lsm.fit = LSM(Y=School9Network,edgeCov=School9EdgeCov, senderCov=School9NodeCov, receiverCov=School9NodeCov, estimate.intercept=0, niter = niter)
Data set included with the HLSM package: network variables from Pitts and Spillane (2009).
ps.advice.mat ps.advice.df ps.all.vars.mat ps.edge.vars.mat ps.edge.df ps.school.vars.mat ps.teacher.vars.mat ps.node.df School9Network School9NodeCov School9EdgeCovps.advice.mat ps.advice.df ps.all.vars.mat ps.edge.vars.mat ps.edge.df ps.school.vars.mat ps.teacher.vars.mat ps.node.df School9Network School9NodeCov School9EdgeCov
ps.advice.mat: a list of 15 sociomatrices of advice seeking network, one for each school.
ps.advice.df: a data frame of all ties.
ps.all.vars.mat: a list of 15 arrays of all the covariates, one for each school. edge.vars.mat: a list of edge level covariates for 15 different school.
ps.edge.df: a dataframe of all edge covariates.
ps.school.vars.mat: a list of school level covariates for all 15 schools.
ps.teacher.vars.mat: a list of node level covariates for all 15 schools.
ps.node.df: a dataframe of all node covariates.
ps.all.vars.mat: a single list of length 15 containing the covariates mentioned above.
School9Network: a single adjacency matrix from School 9.
School9NodeCov: a dataframe with node covariates
School9EdgeCov: a dataframe with dyad-level covariates.
Sam Adhikari and Tracy Sweet
Pitts, V., & Spillane, J. (2009). "Using social network methods to study school leadership".International Journal of Research & Method in Education, 32, 185-207
Sweet, T.M., Thomas, A.C., and Junker, B.W. (2013). "Hierarchical Network Models for Education Research: Hierarchical Latent Space Models". Journal of Educational and Behavorial Statistics.